@@ -241,13 +241,13 @@ def default_config
 end
 
 def test_config
-  @config ||= default_config.merge({
+  @test_config ||= default_config.merge({
     'store' => :memory,
   })
 end
 
 def test_config_persistent
-  @config ||= default_config.merge({
+  @test_config_persistent ||= default_config.merge({
     'store_options' => {
       'adapter'         => :YAML,
       'adapter_options' => {
@@ -267,6 +267,19 @@ def ssl_test_config
   })
 end
 
+def hooks_config
+  @hooks_config ||= test_config.merge({
+    'hooks' => {
+      'set' => {
+        'set_test_hook' => File.expand_path(File.join(base_dir,'spec/fixtures/set_test_hook.rb'))
+      },
+      'delete' => {
+        'delete_test_hook' => File.expand_path(File.join(base_dir,'spec/fixtures/delete_test_hook.rb'))
+      }
+    }
+  })
+end
+
 def base_dir
   File.dirname(__FILE__)+'/../'
 end
